@@ -5,6 +5,7 @@ OC.L10N.register(
     "{name} (public)" : "{name} (julkinen)",
     "New conversation …" : "Uusi keskustelu…",
     "Participants" : "Osallistujat",
+    "Projects" : "Projektit",
     "Chat" : "Keskustelu",
     "Talk" : "Puhe",
     "Exit fullscreen (f)" : "Poistu koko näytön tilasta (f)",
@@ -29,10 +30,11 @@ OC.L10N.register(
     "Leave call" : "Poistu puhelusta",
     "Join call" : "Liity puheluun",
     "Start call" : "Aloita puhelu",
+    "Calls are disabled in this conversation." : "Puhelut on poistettu käytöstä tässä keskustelussa.",
+    "Go to file" : "Siirry tiedostoon",
     "Share link" : "Jaa linkki",
     "Change password" : "Vaihda salasana",
     "Set password" : "Aseta salasana",
-    "Go to file" : "Siirry tiedostoon",
     "Name" : "Nimi",
     "Conversation name" : "Keskustelun nimi",
     "Rename" : "Nimeä uudelleen",
@@ -44,6 +46,8 @@ OC.L10N.register(
     "No messages yet, start the conversation!" : "Ei vielä viestejä, aloita keskustelu!",
     "New message …" : "Uusi viesti …",
     "Send" : "Lähetä",
+    "You can not send messages, because the conversation is locked." : "Et voi lähettää viestejä, koska keskustelu on lukittu.",
+    "The conversation is locked." : "Keskustelu on lukittu.",
     "Guest" : "Vieras",
     "[Unknown user name]" : "[Tuntematon käyttäjänimi]",
     "Today" : "Tänään",
@@ -97,9 +101,6 @@ OC.L10N.register(
     "Favorited" : "Lisätty suosikkeihin",
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
-    "Always notify" : "Ilmoita aina",
-    "Notify on @-mention" : "Ilmoita @-maininnoista",
-    "Never notify" : "Älä ilmoita koskaan",
     "Leave conversation" : "Poistu keskustelusta",
     "Delete conversation" : "Poista keskustelu",
     "Your screen" : "Sinun näyttösi",
@@ -123,7 +124,9 @@ OC.L10N.register(
     "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Osallistuit puheluun käyttäjien {user1}, {user2}, {user3}, {user4} ja {user5} kanssa",
     "_%n other_::_%n others_" : ["%n muu","%n muuta"],
     "{actor} invited you to {call}" : "{actor} kutsui sinut puheluun {call}",
+    "New in Talk 6" : "Uutta Talkin 6-versiossa",
     "The command does not exist" : "Komentoa ei ole olemassa",
+    "Talk updates ✅" : "Talk-päivitykset ✅",
     "{actor} created the conversation" : "{actor} loi keskustelun",
     "You created the conversation" : "Sinä loit keskustelun",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} muutti keskustelun \"%1$s\" uudeksi nimeksi \"%2$s\"",
@@ -134,6 +137,10 @@ OC.L10N.register(
     "You joined the call" : "Sinä liityit puheluun",
     "{actor} left the call" : "{actor} poistui puhelusta",
     "You left the call" : "Sinä poistuit puhelusta",
+    "{actor} unlocked the conversation" : "{actor} poisti keskustelun lukituksen",
+    "You unlocked the conversation" : "Poistit keskustelun lukituksen",
+    "{actor} locked the conversation" : "{actor} lukitsi keskustelun",
+    "You locked the conversation" : "Sinä lukitsit keskustelun",
     "{actor} allowed guests" : "{actor} salli vieraat",
     "You allowed guests" : "Sinä sallit vieraat",
     "{actor} disallowed guests" : "{actor} esti vieraat",
@@ -180,16 +187,14 @@ OC.L10N.register(
     "{user} mentioned you in conversation {call}" : "{user} mainitsi sinut keskustelussa {call}",
     "A deleted user mentioned you in conversation {call}" : "Poistettu käyttäjä mainitsi sinut keskustelussa {call}",
     "A guest mentioned you in conversation {call}" : "Vieras mainitsi sinut keskustelussa {call}",
-    "%s invited you to a private conversation" : "%s kutsui sinut yksityiskeskusteluun",
     "{user} invited you to a private conversation" : "{user} kutsui sinut yksityiskeskusteluun",
-    "%s invited you to a group conversation: %s" : "%s kutsui sinut ryhmäkeskusteluun: %s",
     "{user} invited you to a group conversation: {call}" : "{user} kutsui sinut ryhmäkeskusteluun: {call}",
     "{user} wants to talk with you" : "{user} haluaa puhua kanssasi",
     "A group call has started in {call}" : "Ryhmäpuhelu on alkanut puhelussa {call}",
     "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päiväyksen muoto tulee olla YYYY-MM-DD",
     "Conversation not found" : "Keskustelua ei löydy",
     "Path is already shared with this room" : "Polku on jo jaettu tämän huoneen kesken",
-    "Video & audio-conferencing using WebRTC" : "Video- ja äänipuheluita WebRTC:tä käyttäen",
+    "Chat, video & audio-conferencing using WebRTC" : "Keskustelu ja video- sekä äänineuvottelut WebRTC:tä käyttäen",
     "User" : "Käyttäjä",
     "Everyone" : "Kaikki",
     "Disabled" : "Pois käytöstä",
@@ -212,12 +217,14 @@ OC.L10N.register(
     "Saved!" : "Tallennettu!",
     "Commands" : "Komennot",
     "Command" : "Komento",
+    "Select a conversation to add to the project" : "Valitse projektiin lisättävä keskustelu",
+    "Select conversation" : "Valitse keskustelu",
     "Saved" : "Tallennettu",
     "Add a new server" : "Lisää uusi palvelin",
     "Shared secret" : "Jaettu salaisuus",
     "STUN servers" : "STUN-palvelimet",
     "TURN servers" : "TURN-palvelin",
-    "This call is password-protected" : "Tämä puhelu on salasanasuojattu",
+    "This conversation is password-protected" : "Tämä keskustelu on salasanasuojattu",
     "The password is wrong. Try again." : "Salasana on väärin. Yritä uudelleen.",
     "TURN server" : "TURN-palvelin",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-palvelinta käytetään liikenteen välittämisessä palomuurin takana oleville osallistujille.",
@@ -225,6 +232,7 @@ OC.L10N.register(
     "Join conversations at any time, any where, on any device." : "Liity keskusteluun milloin tahansa, mistä tahansa, miltä laitteelta tahansa.",
     "Android app" : "Android-sovellus",
     "iOS app" : "iOS-sovellus",
+    "Link to a conversation" : "Linkki keskusteluun",
     "Delete server" : "Poista palvelin",
     "Add new server" : "Lisää uusi palvelin",
     "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Poistit kaikki STUN-palvelimet. Koska STUN-palvelinta tarvitaan lähes aina, lisäsimme oletuksena käytettävän STUN-palvelimen.",
@@ -234,6 +242,7 @@ OC.L10N.register(
     "Test server" : "Testaa palvelin",
     "New public conversation" : "Uusi julkinen keskustelu",
     "New group conversation" : "Uusi ryhmäkeskustelu",
+    "Password request by %s" : "Salasanaa pyysi %s",
     "_%n other guest_::_%n other guests_" : ["%n muu vieras","%n muuta vierasta"],
     ", " : ",",
     "%s mentioned you in a private conversation" : "%s mainitsi sinut yksityskeskustelussa",
@@ -246,17 +255,27 @@ OC.L10N.register(
     "A guest mentioned you in a group conversation: %s" : "Vieras mainitsi sinut ryhmäkeskustelussa: %s",
     "A guest mentioned you in a group conversation: {call}" : "Vieras mainitsi sinut ryhmäkeskustelussa: {call}",
     "A guest mentioned you in a group conversation" : "Vieras mainitsi sinut ryhmäkeskustelussa",
+    "%s invited you to a private conversation" : "%s kutsui sinut yksityiskeskusteluun",
+    "%s invited you to a group conversation: %s" : "%s kutsui sinut ryhmäkeskusteluun: %s",
     "%s invited you to a group conversation" : "%s kutsui sinut ryhmäkeskusteluun",
     "{user} invited you to a group conversation" : "{user} kutsui sinut ryhmäkeskusteluun",
     "A group call has started" : "Ryhmäpuhelu on alkanut",
     "{email} requested the password to access a share" : "{email} pyysi salasanaa käyttääkseen jakoa",
     "Unnamed conversation" : "Nimetön keskustelu",
+    "Video & audio-conferencing using WebRTC" : "Video- ja äänipuheluita WebRTC:tä käyttäen",
+    "This call is password-protected" : "Tämä puhelu on salasanasuojattu",
+    "Always notify" : "Ilmoita aina",
+    "Notify on @-mention" : "Ilmoita @-maininnoista",
+    "Never notify" : "Älä ilmoita koskaan",
     "Join now" : "Liity nyt",
     "{user} sent a message in a conversation" : "{user} lähetti viestin keskusteluun",
     "A deleted user sent a message in a conversation" : "Poistettu käyttäjä lähetti viestin keskusteluun",
     "A guest sent a message in a conversation" : "Vieras lähetti viestin keskusteluun",
     "{user} mentioned you in a conversation" : "{user} mainitsi sinut keskustelussa",
     "A deleted user mentioned you in a conversation" : "Poistettu käyttäjä mainitsi sinut keskustelussa",
-    "A guest mentioned you in a conversation" : "Vieras mainitsi sinut keskustelussa"
+    "A guest mentioned you in a conversation" : "Vieras mainitsi sinut keskustelussa",
+    "{email} requested the password to access {file}" : "{email} pyysi salasanaa voidakseen käsitellä tiedostoa {file}",
+    "Someone requested the password to access {file}" : "Joku pyysi salasanaa voidakseen käsitellä tiedostoa {file}",
+    "* Microsoft Edge and Safari can now be used to participate in audio and video calls" : "* Microsoft Edgeä ja Safaria voi nyt käyttää ääni- ja videopuheluissa"
 },
 "nplurals=2; plural=(n != 1);");
